"use strict";var n=function(t,r){return function(){return r||t((r={exports:{}}).exports,r),r.exports}};var i=n(function(a,e){
var u=require('@stdlib/utils-type-of/dist');function s(t){return u(t)==="function"}e.exports=s
});var c=i();module.exports=c;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
